Enum Commands
enum Commands {
Client {
host: String,
},
Daemon {},
GenerateConfig {
ssh_config_path: Option<String>,
program: Option<String>,
arguments: Vec<String>,
cluster: String,
output: Option<String>,
},
}Expand description
The command CLI subcommand
Variants
Client
Subcommand that will launch a single client window
connecting to the given host with the given username. It will also try to read input from a daemon via the named pipe.
Daemon
Subcommand that will launch the daemon window.
The daemon is responsible to launch the client windows, one for each given host. For each client a named pipe will be created and any keystrokes the daemon window receives are forwarded via the pipes to all the clients. Also handles control mode.
GenerateConfig
Write a default config file at the given output path.
Values that differ from the defaults can be set via the options.
Fields
ssh_config_path: Option<String>Path to an SSH config file. When set, the launched program
receives -F <PATH> as the first two argv entries.
program: Option<String>Program launched to establish each SSH connection.
Defaults to the client.program config default when unset.